using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Cryptography.X509Certificates;
using System.Text;
using System.Threading.Tasks;

namespace Programmation_objet_TLESIO21.TD2 {
    public static class Td2 {

        public static void Exo1() {
            TabClasse t = new TabClasse(5);
            t.RemplirTableau();
            Console.Write("Le tableau est : ");
            t.AfficherTableau();

            Console.Write("Après tri, le tableau est : ");
            t.TrierTableau();
            t.AfficherTableau();

            Console.WriteLine("Get de l'index 8 : " + t[8]);//error
            Console.WriteLine("Get de l'index 2 : " + t[2]); //ok

            Console.Write("Set de 15 à l'index 9 : ");
            t[9] = 15; //error
            t.AfficherTableau();

            Console.Write("Set de 15 à l'index 1 : ");
            t[1] = 15; //ok
            t.AfficherTableau();

        }

        public static void Exo3() {
            Personnes Tableau = new Personnes(4);
            Tableau[0] = "Anna";
            Tableau[1] = "Ingrid";
            Tableau[2] = "Maria";
            Tableau[3] = "Ulrika";
            Console.WriteLine(Tableau[1]); // Affiche "Ingrid"
            Console.WriteLine(Tableau["Maria"]); //Affiche 2
            Console.WriteLine(Tableau[10]); // Affiche null
            Console.WriteLine(Tableau["Toto"]); //Affiche -1
        }
        public static void Launch() {
            //Exo1();
            Exo3();

        }
    }
}
